from flask_restx import fields, Namespace  

usage_ns = Namespace('usage', description='Usage transcription data, export, price and cost update operations')

usage_cost_model = usage_ns.model('UpdateUsageCost', {
    'company_ids': fields.List(fields.String, required=False, description='Company id list'),
    'start_date': fields.String(required=True, description='Start date (YYYY-MM-DD)'),
    'end_date': fields.String(required=True, description='End date (YYYY-MM-DD)'),
    'product': fields.String(required=True, description='Product name'),
    'price': fields.String(required=True, description='Price'),
    'billing_unit': fields.Integer(required=True, description='Billing unit')
})

model_price_update = usage_ns.model('UpdateModelPrice', {
    'product': fields.String(required=False),
    'provider': fields.String(required=False),
    'type': fields.String(required=False),
    'billingBy': fields.String(required=False),
    'billingUnit': fields.Integer(required=False),
    'currency': fields.String(required=False),
    'price': fields.String(required=False),
    'clientPrice': fields.String(required=False),
})

model_prices_query_params = {
    'type': {
        'description': 'Type of the model. Ex: stt, tts (Optional)',
        'type': 'string'
    },
    'provider': {
        'description': 'The API provider. E.g., google, openai, meta (Optional)',
        'type': 'string'
    },
}


transcription_data_query_params = {
    'companyId': {
        'description': 'Company ID (required)',
        'type': 'string'
    },
    'startDate': {
        'description': 'Start date (YYYY-MM-DD) (required)',
        'type': 'string'
    },
    'endDate': {
        'description': 'End date (YYYY-MM-DD) (required)',
        'type': 'string'
    },
    'who': {
        'description': 'Who made: "hit" or "client" (required)',
        'type': 'string'
    }
}
